import com.google.gson.stream.JsonReader;

import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;

public class Main {
    public static void main(String[] args) throws IOException {
        File file = new File("src/main/resources/users.json");

        // Создаем ридер
        JsonReader reader = new JsonReader(new FileReader(file));
        // Читаем json файл
        List<User> users = getUsers(reader);
        // Выводим результат
        users.forEach(System.out::println);
        // обязательно закрываем ридер
        reader.close();
    }

    /**
     * Возвращает список всех пользователей
     *
     * @param reader Ридер
     * @return список всех пользователей
     */
    private static List<User> getUsers(JsonReader reader) throws IOException {
        List<User> users = new ArrayList<User>();

        // начало обработки списка
        reader.beginArray();
        while (reader.hasNext()) {
            // читаем информацию о пользователе
            User user = readUser(reader);
            users.add(user);
        }
        // конец обработки списка
        reader.endArray();

        return users;
    }

    /**
     * Возвращает очередного пользователя
     *
     * @param reader Ридер
     * @return Информацию о пользователе
     */
    private static User readUser(JsonReader reader) throws IOException {
        int id = 0;
        String firstName = "";
        String lastName = "";

        // начало обработки объекта
        reader.beginObject();
        while (reader.hasNext()) {
            String name = reader.nextName();
            if (name.equals("id")) {
                id = reader.nextInt();
            } else if (name.equals("first_name")) {
                firstName = reader.nextString();
            } else if (name.equals("last_name")) {
                lastName = reader.nextString();
            }
        }
        // конец обработки объекта
        reader.endObject();

        return new User(id, firstName, lastName);
    }
}
